@@ -1,7 +1,7 @@
 package Data::Sah::Coerce;
 
-our $DATE = '2016-05-16'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2016-05-17'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -30,6 +30,12 @@ sub _list_rule_modules {
 $SPEC{gen_coercer} = {
     v => 1.1,
     summary => 'Generate coercer code',
+    description => <<'_',
+
+This is mostly for testing. Normally the coercion rules will be used from
+`Data::Sah`.
+
+_
     args => {
         type => {
             schema => 'str*', # XXX sah::typename
@@ -149,7 +155,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.001 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-05-16.
+This document describes version 0.002 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-05-17.
 
 =head1 SYNOPSIS
 
@@ -174,7 +180,7 @@ This distribution contains a standard set of coercion rules for L<Data::Sah>. It
 is separated from the C<Data-Sah> distribution and can be used independently.
 
 A coercion rule is put in
-C<Data::Sah::Coerce::$LANG::$TARGET_TYPE::$SOURCE_TYPE_AND_EXTRA_DESCRIPTION>
+C<Data::Sah::Coerce::$COMPILER::$TARGET_TYPE::$SOURCE_TYPE_AND_EXTRA_DESCRIPTION>
 module, for example: L<Data::Sah::Coerce::perl::date::int_epoch> for converting
 date from integer (Unix epoch) or L<Data::Sah::Coerce::perl::date::str_iso8601>
 for converting date from ISO8601 strings like "2016-05-15".
@@ -195,6 +201,22 @@ rule names to enable explicitly (e.g. C<< ["int_epoch", "str_8601"] >>. On the
 other hand, to explicitly disable an enabled-by-default rule, one can use the
 C<x.dont_coerce_from> (or C<x.perl.dont_coerce_from>, etc).
 
+=item * might_die => bool (default: 0)
+
+Whether the rule will generate code that might die (e.g. does not trap failure
+in a conversion process). An example of a rule like this is coercing from string
+in the form of "YYYY-MM-DD" to a DateTime object. The rule might match any
+string in the form of C<< /\A(\d{4})-(\d{2})-(\d{2})\z/ >> and feed it to C<<
+DateTime->new >>, without checking of a valid date, so the latter might die.
+
+An example of rule that "might not die" is coercing from a comma-separated
+string into array. This process should not die unless under extraordinary
+condition (e.g. out of memory).
+
+For a rule that might die, the program/library that uses the rule module might
+add an eval block around the expr_coerce code that is generated by the rule
+module.
+
 =back
 
 The module must also contain C<coerce> subroutine which must generate the code
@@ -238,6 +260,26 @@ A list of modules required by the expressions.
 
 =back
 
+Basically, the C<coerce> subroutine must generates a code that accepts a
+non-undef data and must convert this data to the desired type/format under the
+right condition. The code to match the right condition must be put in
+C<expr_match> and the code to convert data must be put in C<expr_coerce>.
+
+Program/library that uses Data::Sah::Coerce can collect rules from the rule
+modules then compose them into the final code, something like (in pseudocode):
+
+ if (data is undef) {
+   return undef;
+ } elsif (data matches expr-match-from-rule1) {
+   return expr-coerce-from-rule1;
+ } elsif (data matches expr-match-from-rule2) {
+   return expr-coerce-from-rule1;
+ ...
+ } else {
+   # does not match any expr-match
+   return original data;
+ }
+
 =head1 VARIABLES
 
 =head2 $Log_Coercer_Code => bool (default: from ENV or 0)
@@ -256,6 +298,9 @@ something like:
 
 Generate coercer code.
 
+This is mostly for testing. Normally the coercion rules will be used from
+C<Data::Sah>.
+
 This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
@@ -304,6 +349,8 @@ feature.
 
 L<Data::Sah>
 
+L<Data::Sah::CoerceJS>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
