@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::obj_DateTime;
 
-our $DATE = '2016-05-16'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2016-05-17'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,7 +37,8 @@ sub coerce {
         $res->{modules}{'Time::Moment'} //= 0;
         $res->{expr_coerce} = "Time::Moment->from_object($dt)";
     } else {
-        die "BUG: Unknown coerce_to value '$coerce_to'";
+        die "BUG: Unknown coerce_to value '$coerce_to', ".
+            "please use int(epoch), DateTime, or Time::Moment";
     }
 
     $res;
@@ -58,7 +59,7 @@ Data::Sah::Coerce::perl::date::obj_DateTime - Coerce date from DateTime object
 
 =head1 VERSION
 
-This document describes version 0.001 of Data::Sah::Coerce::perl::date::obj_DateTime (from Perl distribution Data-Sah-Coerce), released on 2016-05-16.
+This document describes version 0.002 of Data::Sah::Coerce::perl::date::obj_DateTime (from Perl distribution Data-Sah-Coerce), released on 2016-05-17.
 
 =for Pod::Coverage ^(meta|coerce)$
 
