@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::obj_TimeMoment;
 
-our $DATE = '2016-05-16'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2016-05-17'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,14 +37,15 @@ sub coerce {
     } elsif ($coerce_to eq 'Time::Moment') {
         $res->{expr_coerce} = $dt;
     } else {
-        die "BUG: Unknown coerce_to value '$coerce_to'";
+        die "BUG: Unknown coerce_to value '$coerce_to', ".
+            "please use int(epoch), DateTime, or Time::Moment";
     }
 
     $res;
 }
 
 1;
-# ABSTRACT: Coerce date from DateTime object
+# ABSTRACT: Coerce date from Time::Moment object
 
 __END__
 
@@ -54,11 +55,11 @@ __END__
 
 =head1 NAME
 
-Data::Sah::Coerce::perl::date::obj_TimeMoment - Coerce date from DateTime object
+Data::Sah::Coerce::perl::date::obj_TimeMoment - Coerce date from Time::Moment object
 
 =head1 VERSION
 
-This document describes version 0.001 of Data::Sah::Coerce::perl::date::obj_TimeMoment (from Perl distribution Data-Sah-Coerce), released on 2016-05-16.
+This document describes version 0.002 of Data::Sah::Coerce::perl::date::obj_TimeMoment (from Perl distribution Data-Sah-Coerce), released on 2016-05-17.
 
 =for Pod::Coverage ^(meta|coerce)$
 
