@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_iso8601;
 
-our $DATE = '2016-05-16'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2016-05-17'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,7 @@ use warnings;
 sub meta {
     +{
         enable_by_default => 1,
+        might_die => 1, # we match any (YYYY-MM-DD... string, so the conversion to date might fail on invalid dates)
     };
 }
 
@@ -40,7 +41,8 @@ sub coerce {
         $res->{modules}{"Time::Moment"} //= 0;
         $res->{expr_coerce} = "Time::Moment->from_epoch($code_epoch)";
     } else {
-        die "BUG: Unknown coerce_to value '$coerce_to'";
+        die "BUG: Unknown coerce_to value '$coerce_to', ".
+            "please use int(epoch), DateTime, or Time::Moment";
     }
 
     $res;
@@ -61,7 +63,7 @@ Data::Sah::Coerce::perl::date::str_iso8601 - Coerce date from (a subset of) ISO8
 
 =head1 VERSION
 
-This document describes version 0.001 of Data::Sah::Coerce::perl::date::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2016-05-16.
+This document describes version 0.002 of Data::Sah::Coerce::perl::date::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2016-05-17.
 
 =head1 DESCRIPTION
 
